Compares new_data against what is currently stored and returns only the diff (new or changed values).

bq_get_db_diff(new_data, con = NULL, frequency = "monthly")

Arguments

new_data

data.frame with freshly pulled DHIS data

con

A DBI BigQuery connection (or NULL to create one)

frequency

Either "weekly" or "monthly"

Value

data.table of rows that are new or have changed values