Get the data from new data that differs from what is present in the database

get_db_diff(new_data, db_path)

Arguments

new_data

data.frame with new data for comparison to the data in the database

db_path

Location of the database

Value

data.frame with the data from new data that differs from what is present in the database