Get the names of the variables that uniquely identify an observation

get_id_vars(db_path)

Arguments

db_path

Location of the database

Value

Vector of column names that uniquely identify an observation