A list of all health facilities and administrative units, and their parent-child relationships

loc_table

Format

A data frame with 11219 rows and 9 columns:

location_name

Name of Geographic Entity

location_id

DHIS2 assigned ID for geographic entity

parent_id

DHIS2 assigned ID of parent geographic entity

level

DHIS2 assigned hierarchical level

path_to_top_parent

string of DHIS2 IDs from current geographic entity to Uganda as a whole

region_name

name of region associated with geographic entity. Blank is entity is region

district_name

name of district associated with geographic entity. Blank is entity is district

DLG_name

name of DLG (District Level Government) associated with geographic entity. Blank is entity is DLG

subcounty_name

name of subcounty associated with geographic entity. Blank is entity is subcounty