An R readable, valid, shapefile with subcounty shapes combatible with administrative hierarchies in loc_table

uga_subcounty_shp

Format

A shapefile with 2204 rows and 8 variables

name

Name of Subcounty

id

DHIS2 assigned ID of Subcounty

geometry

geometry of subcounty (polygon or multipolygon)

dup_geom

indicator flag if the geometry is shared with another subcounty and cannot be resolved

split_sc

indicator flag that geometry needs to be split, but has not been done

shp_as_district

indicator flag if the subcounty shape is unknown and has therefore been assigned the district shape

district_name

Name of parent district of subcounty