bq_get_db_diff.Rd
Compares new_data against what is currently stored and returns only the diff (new or changed values).
new_data
bq_get_db_diff(new_data, con = NULL, frequency = "monthly")
data.frame with freshly pulled DHIS data
A DBI BigQuery connection (or NULL to create one)
Either "weekly" or "monthly"
"weekly"
"monthly"
data.table of rows that are new or have changed values