bq_get_imputed_sample.RdReturns a random sample of rows from the imputed facility data table. Useful for computing outlier summaries without reading the full table.
bq_get_imputed_sample(con = NULL, frequency = "monthly", n = 500000L)data.table with sampled imputed data