Get the data from a database with the option to subset to a specified version and id values
get_data(db_path, id_list = NULL, version_id = NULL)
Arguments
- db_path
Location of the database
- id_list
A list of id names and values, if NULL, pulls full table
- version_id
Integer version number, if NULL, pulls latest version