get_db_diff.Rd
Get the data from new data that differs from what is present in the database
get_db_diff(new_data, db_path)
data.frame with new data for comparison to the data in the database
Location of the database
data.frame with the data from new data that differs from what is present in the database