get_period_range.RdGet the a vector of periods follow DHIS formatting that spans that start and end period provided
get_period_range(frequency, year_start, sub_year_start, year_end, sub_year_end)A vector of periods following the DHIS formatting standard of either YYYYW{week number with no leading zero} or YYYY{month number with a leading zero for single digit integers}