health_facility_table.RdA comprehensive list of health facilities and administrative hierarchies, including ownership, operational status, and geographic coordinates.
health_facility_tableA data frame with 8676 rows and 22 columns:
Name of Health facility
DHIS2 assigned ID for health facility
DHIS2 assigned ID of parent health facility (subcounty)
DHIS2 assigned hierarchical level
The governing body or authority responsible for the facility
The original classification level of the health facility
The medical bureau affiliation (e.g., UPMB, UCMB)
Current status of the facility (e.g., Functional, Non-Functional)
Type of ownership (e.g., Public, Private, PNFP)
Indicator for private sector classification (PFP, PNFP)
Indicator for public sector classification (e.g. MOH,BOU, Local Government)
Current status of data reporting compliance
String of DHIS2 IDs from current health facility to the top-level parent
Name of region associated with health facility
Name of district associated with health facility
Name of District Local Government (DLG) associated with health facility
Name of subcounty associated with health facility
Geographic coordinate: North-South position
Geographic coordinate: East-West position
Indicator if geometry was added through external web-scraping and not present in DHIS2
Secondary facility level classification (clinic, hospital, drugshop, other)
Secondary facility label created to match other surveys on health seeking (private, gov_HC, private_hosp, drugshop, gov_hosp, other)