loc_table.RdA list of all health facilities and administrative units, and their parent-child relationships
loc_tableA data frame with 11219 rows and 9 columns:
Name of Geographic Entity
DHIS2 assigned ID for geographic entity
DHIS2 assigned ID of parent geographic entity
DHIS2 assigned hierarchical level
string of DHIS2 IDs from current geographic entity to Uganda as a whole
name of region associated with geographic entity. Blank is entity is region
name of district associated with geographic entity. Blank is entity is district
name of DLG (District Level Government) associated with geographic entity. Blank is entity is DLG
name of subcounty associated with geographic entity. Blank is entity is subcounty