uga_subcounty_shp.RdAn R readable, valid, shapefile with subcounty shapes combatible with administrative hierarchies in loc_table
uga_subcounty_shpA shapefile with 2204 rows and 8 variables
Name of Subcounty
DHIS2 assigned ID of Subcounty
geometry of subcounty (polygon or multipolygon)
indicator flag if the geometry is shared with another subcounty and cannot be resolved
indicator flag that geometry needs to be split, but has not been done
indicator flag if the subcounty shape is unknown and has therefore been assigned the district shape
Name of parent district of subcounty